aboutsummaryrefslogtreecommitdiffstats
path: root/python/servo/command_base.py
diff options
context:
space:
mode:
Diffstat (limited to 'python/servo/command_base.py')
-rw-r--r--python/servo/command_base.py8
1 files changed, 4 insertions, 4 deletions
diff --git a/python/servo/command_base.py b/python/servo/command_base.py
index d8adb293aa9..4b5de868531 100644
--- a/python/servo/command_base.py
+++ b/python/servo/command_base.py
@@ -569,15 +569,15 @@ class CommandBase(object):
android_api = android_platform.replace('android-', '')
# Check if the NDK version is 25
if not os.path.isfile(path.join(env["ANDROID_NDK_ROOT"], 'source.properties')):
print("ANDROID_NDK should have file `source.properties`.")
print("The environment variable ANDROID_NDK_ROOT may be set at a wrong path.")
sys.exit(1)
with open(path.join(env["ANDROID_NDK_ROOT"], 'source.properties'), encoding="utf8") as ndk_properties:
lines = ndk_properties.readlines()
- if lines[1].split(' = ')[1].split('.')[0] != '25':
- print("Servo currently only supports NDK r25c.")
+ if lines[1].split(' = ')[1].split('.')[0] != '26':
+ print("Servo currently only supports NDK r26c.")
sys.exit(1)
# Android builds also require having the gcc bits on the PATH and various INCLUDE
@@ -633,7 +633,7 @@ class CommandBase(object):
env['TARGET_STRIP'] = to_ndk_bin("llvm-strip")
env['RUST_FONTCONFIG_DLOPEN'] = "on"
- env["LIBCLANG_PATH"] = path.join(llvm_toolchain, "lib64")
+ env["LIBCLANG_PATH"] = path.join(llvm_toolchain, "lib")
env["CLANG_PATH"] = to_ndk_bin("clang")
# A cheat-sheet for some of the build errors caused by getting the search path wrong...
@@ -569,15 +569,15 @@ class CommandBase(object):
android_api = android_platform.replace('android-', '')
- # Check if the NDK version is 25
+ # Check if the NDK version is 26
if not os.path.isfile(path.join(env["ANDROID_NDK_ROOT"], 'source.properties')):
print("ANDROID_NDK should have file `source.properties`.")